################################################################
#               Amlodipine Example                             #
#         Effect size: mean difference                         #
################################################################
#
# Data in the first group (sample size, mean, and variance
n1    <- c(    46,     30,     75,     12,     32,     31,     27,     46)
x1    <- c(0.2316, 0.2811, 0.1894, 0.0930, 0.1622, 0.1837, 0.6612, 0.1366)
var1  <- c(0.2254, 0.1441, 0.1981, 0.1389, 0.0961, 0.1246, 0.7060, 0.1211)
#
# Data in the second group (sample size, mean, and variance
n2    <- c(     48,     26,     72,     12,     34,     31,      27,      47)
x2    <- c(-0.0027, 0.0270, 0.0443, 0.2277, 0.0056, 0.0943, -0.0057, -0.0057)
var2  <- c( 0.0007, 0.1139, 0.4972, 0.0488, 0.0955, 0.1734,  0.9891,  0.1291)
#
#
# Calculate the difference of means
Di   <- x1 - x2
# Calculate the variance estimate
var.Di <- var1 / n1 + var2 / n2
#
# Load meta package
library(meta)
#
# Generic inverse variance meta-analysis
# Note: the second argument must be the vector of STANDARD ERRORS
# Use of the function sqrt (square root)
meta1 <- metagen(Di, sqrt(var.Di), sm="MD")
# 
# Print all the information of the object meta1
print(meta1)
# Print only information about meta-analysis results
summary(meta1)
# Class of the meta1 object
class(meta1)
# Structure of the meta1 object
str(meta1)
# Forest plot
forest(meta1)

##############################################################################################################
# Use escalc function in package metafor and then apply metagen in package meta
library(metafor)
#
dat1 <-  escalc(measure="MD", n1i = n1, n2i = n2, m1i = x1, m2i = x2, sd1i = sqrt(var1), sd2i = sqrt(var2) )
str(dat1)
class(dat1)
#
meta2 <- metagen(yi, sqrt(vi), sm="MD", data=dat1)
summary(meta2)
#
# Empirical Bayes and Paule-Mandel approach are identical
#
summary(update(meta2, method.tau="PM"))
summary(update(meta2, method.tau="EB"))
summary(update(meta2, method.tau="PM", hakn=TRUE))





