require("bayesmeta")
source("plotfun.R")
data("CrinsEtAl2014")

print(CrinsEtAl2014)

require("metafor")

crins.srr <- escalc(measure="OR",
                    ai=exp.SRR.events,  n1i=exp.total,
                    ci=cont.SRR.events, n2i=cont.total,
                    slab=publication,   data=CrinsEtAl2014[c(1,4,6),])

###################
# FOREST PLOT:

require("forestplot")
labtext <- matrix(NA_character_, nrow=4, ncol=5)
labtext[,1] <- c("publication", crins.srr$publication)
labtext[,2] <- c("treatment", paste0(crins.srr$exp.SRR.events, " / ", crins.srr$exp.total))
labtext[,3] <- c("control", paste0(crins.srr$cont.SRR.events, " / ", crins.srr$cont.total))
labtext[,4] <- c("log-OR", sprintf("%.3f",crins.srr$yi,2))
labtext[,5] <- c("std. err.", sprintf("%.3f",sqrt(crins.srr$vi),2))
horizl <- list(grid::gpar(col="darkgrey"))
names(horizl) <- as.character(c(2))
q975 <- qnorm(0.975)

pdf(file="E:/Vellore-Stick/Presentation/Bayyes1.pdf", paper="special", width=7, height=2)
forestplot(labeltext=labtext,
           hrzl=horizl,
           mean=c(NA,crins.srr$yi),
           lower=c(NA,crins.srr$yi-q975*sqrt(crins.srr$vi)),
           upper=c(NA,crins.srr$yi+q975*sqrt(crins.srr$vi)),
           xlab="log-OR",
           txt_gp = fpTxtGp(ticks = gpar(cex=1), xlab = gpar(cex=0.9)))
 dev.off()



###################
# MA computations:

tauHat <- c("DL"  =sqrt(rma(crins.srr,method="DL")$tau2),
            "REML"=sqrt(rma(crins.srr,method="REML")$tau2),
            "PM"  =sqrt(rma(crins.srr,method="PM")$tau2))

# uniform prior (for likelihood plot):
crins.ma0 <- bayesmeta(crins.srr)

#crins.ma1 <- bayesmeta(y=crins.srr$yi, sigma=sqrt(crins.srr$vi),
#                       labels=crins.srr$publication,
#                       mu.prior.mean=0, mu.prior.sd=4,
#                       tau.prior=function(x){return(dhalfnormal(x, scale=0.5))})

crins.ma1 <- bayesmeta(crins.srr,
                       mu.prior.mean=0, mu.prior.sd=4,
                       tau.prior=function(x){return(dhalfnormal(x, scale=0.5))})

crins.ma2 <- bayesmeta(crins.srr,
                       mu.prior.mean=0, mu.prior.sd=4,
                       tau.prior=function(x){return(dhalfnormal(x, scale=1.0))})

crins.ma3 <- bayesmeta(crins.srr,
                       mu.prior.mean=0, mu.prior.sd=4,
                       tau.prior=function(x){return(dexp(x, rate=1/0.5))})

ma01 <- bayesmeta(y=c(-1.998, -0.446, -1.877), sigma=c(0.911, 0.676, 1.142),
                  labels=c("Heffron (2003)","Ganschow (2005)","Gras (2008)"),
                  mu.prior.mean=0.0, mu.prior.sd=4.0,
                  tau.prior=function(x){return(dhalfnormal(x, scale=0.5))})

#########################
# joint likelihood plot:
plotsize <- c("height"=5, "width"=5)

#postscript(file="~/lehre/2017-04-InSPiRe/Likelihood.eps", title="R Graphics Output",
#           paper="special", width=plotsize["width"], height=plotsize["height"], horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot.bayesmeta(crins.ma0, which=2, main="",
               maxtau=2.7, murange=c(-3.5,1), likeli=TRUE)
par(mar=c(5,4,4,2)+0.1)
dev.off()

#########################
# joint posterior plot:
# HN(0.5) prior:
#postscript(file="~/lehre/2017-04-InSPiRe/Posterior01.eps", title="R Graphics Output",
#           paper="special", width=plotsize["width"], height=plotsize["height"], horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot.bayesmeta(crins.ma1, which=2, main="",
               maxtau=2.7, murange=c(-3.5,1))
par(mar=c(5,4,4,2)+0.1)
dev.off()

#########################
# marginal density plots:

# tau posterior:
#postscript(file="~/lehre/2017-04-InSPiRe/MarginalTau01.eps", title="R Graphics Output",
#           paper="special", width=plotsize["width"], height=plotsize["height"], horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot.bayesmeta(crins.ma1, which=4, main="",
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)
legend("topright", lty=c("dashed", "solid"), leg=c("prior","posterior"),)
par(mar=c(5,4,4,2)+0.1)
dev.off()

# mu posterior:
#postscript(file="~/lehre/2017-04-InSPiRe/MarginalMu01.eps", title="R Graphics Output",
#           paper="special", width=plotsize["width"], height=plotsize["height"], horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot.bayesmeta(crins.ma1, which=3, main="",
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)
legend("topright", lty=c("dashed", "solid"), leg=c("prior","posterior"),)
par(mar=c(5,4,4,2)+0.1)
dev.off()

#######################
# FOREST PLOT:
#postscript(file="~/lehre/2017-04-InSPiRe/CrinsForest02.eps", title="R Graphics Output",
#           paper="special", width=7, height=3, horiz=F)
forestplot(crins.ma1,
           shrink=FALSE,
           xlab="odds ratio", expo=TRUE, xlog=TRUE, digi=3, 
           txt_gp = fpTxtGp(ticks = gpar(cex=1), xlab = gpar(cex=0.9)))
dev.off()

#postscript(file="~/lehre/2017-04-InSPiRe/CrinsForest03.eps", title="R Graphics Output",
#           paper="special", width=7, height=3.5, horiz=F)
forestplot(crins.ma1,
           shrink=TRUE,
           xlab="odds ratio", expo=TRUE, xlog=TRUE, digi=3, 
           txt_gp = fpTxtGp(ticks = gpar(cex=1), xlab = gpar(cex=0.9)))
dev.off()

##############
# EXAMPLE PLOT

#postscript(file="~/lehre/2017-04-InSPiRe/posterior01a.eps", title="R Graphics Output",
#           paper="special", width=6, height=4, horiz=F)
par(mar=c(4,4,0,0)+0.1)
source("~/lehre/2017-04-InSPiRe/rsnippet06a.txt")
par(mar=c(5,4,4,2)+0.1)
dev.off()

#postscript(file="~/lehre/2017-04-InSPiRe/posterior01b.eps", title="R Graphics Output",
#           paper="special", width=6, height=4, horiz=F)
par(mar=c(4,4,0,0)+0.1)
source("~/lehre/2017-04-InSPiRe/rsnippet06a.txt")
source("~/lehre/2017-04-InSPiRe/rsnippet06b.txt")
par(mar=c(5,4,4,2)+0.1)
dev.off()

#postscript(file="~/lehre/2017-04-InSPiRe/posterior02a.eps", title="R Graphics Output",
#           paper="special", width=6, height=4, horiz=F)
par(mar=c(4,4,0,0)+0.1)
source("~/lehre/2017-04-InSPiRe/rsnippet10.txt")
par(mar=c(5,4,4,2)+0.1)
dev.off()

#postscript(file="~/lehre/2017-04-InSPiRe/posterior02b.eps", title="R Graphics Output",
#           paper="special", width=6, height=4, horiz=F)
par(mar=c(4,4,0,0)+0.1)
source("~/lehre/2017-04-InSPiRe/rsnippet10.txt")
abline(v=bm01$post.interval(tau.level=0.95), col="red", lty=2)
par(mar=c(5,4,4,2)+0.1)
dev.off()


bm01 <- bayesmeta(effsize, 
                  mu.prior.mean=0.0, mu.prior.sd=4.0,
                  tau.prior=function(x){dhalfnormal(x,scale=0.5)})
bm02 <- bayesmeta(effsize, 
                  tau.prior=function(x){dhalfnormal(x,scale=1.0)})

mu <- seq(from=-3, to=1, length=100)
#postscript(file="~/lehre/2017-04-InSPiRe/posterior03.eps", title="R Graphics Output",
#           paper="special", width=6, height=4, horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot(mu, bm01$dposterior(mu=mu), type="l", col="blue", xlab="effect (log-OR)", ylab="probability density")
lines(mu, bm02$dposterior(mu=mu), col= "red")
abline(h=0, v=0)
legend("topleft", col=c("blue","red"), pch=15, leg=c("bm01","bm02"))
par(mar=c(5,4,4,2)+0.1)
dev.off()


colvec <- c("blue3", "red3", "green")
x <- seq(0,3,le=200)
plot(c(0,2.7), c(0,1.7), type="n")
lines(x, crins.ma1$dprior(tau=x), col=colvec[1],lty="dashed")
lines(x, crins.ma1$dposterior(tau=x), col=colvec[1])
lines(x, crins.ma2$dprior(tau=x), col=colvec[2],lty="dashed")
lines(x, crins.ma2$dposterior(tau=x), col=colvec[2])
#lines(x, crins.ma3$dprior(tau=x), col=colvec[3],lty="dashed")
#lines(x, crins.ma3$dposterior(tau=x), col=colvec[3])
abline(h=0, v=0, col="darkgrey")

x <- seq(-3.8,1.3,le=200)
plot(c(-3.5,1.0), c(0,0.8), type="n")
lines(x, crins.ma1$dprior(mu=x), col=colvec[1],lty="dashed")
lines(x, crins.ma1$dposterior(mu=x), col=colvec[1])
lines(x, crins.ma2$dprior(mu=x), col=colvec[2],lty="dashed")
lines(x, crins.ma2$dposterior(mu=x), col=colvec[2])
#lines(x, crins.ma3$dprior(mu=x), col=colvec[3],lty="dashed")
#lines(x, crins.ma3$dposterior(mu=x), col=colvec[3])
abline(h=0, v=0, col="darkgrey")


plot.bayesmeta(crins.ma2, which=4,
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)
plot.bayesmeta(crins.ma3, which=4,
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)

# effect posteriors:
plot.bayesmeta(crins.ma1, which=3,
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)
plot.bayesmeta(crins.ma2, which=3,
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)
plot.bayesmeta(crins.ma3, which=3,
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)


crins.ma1$summary
crins.ma2$summary
forestplot(crins.ma2)

###############################################
# NNT

effsize <- escalc(measure="OR",
                    ai=exp.SRR.events,  n1i=exp.total,
                    ci=cont.SRR.events, n2i=cont.total,
                    slab=publication, data=CrinsEtAl2014[c(1,4,6),])
bm01 <- bayesmeta(effsize, 
                    mu.prior.mean=0.0, mu.prior.sd=4.0,
                    tau.prior=function(x){dhalfnormal(x,scale=0.5)})

prob.control <- 0.1
logodds.control <- log(1/9)
logodds.treat <- (logodds.control
                  + bm01$rposterior(n=10000, tau.sample=FALSE))
prob.treat <- exp(logodds.treat) / (1+exp(logodds.treat))
nnt <- 1 / (prob.control-prob.treat)

median(nnt)
quantile(nnt, c(0.025, 0.975))
