require("bayesmeta")
setwd("E:/Vellore-Stick/RPrograms")
source("plotfun.R")
data("CrinsEtAl2014")

print(CrinsEtAl2014)

require("metafor")

crins.srr <- escalc(measure="OR",
                    ai=exp.SRR.events,  n1i=exp.total,
                    ci=cont.SRR.events, n2i=cont.total,
                    slab=publication,   data=CrinsEtAl2014[c(1,4,6),])

###################
# FOREST PLOT:

require("forestplot")
labtext <- matrix(NA_character_, nrow=4, ncol=5)
labtext[,1] <- c("publication", crins.srr$publication)
labtext[,2] <- c("treatment", paste0(crins.srr$exp.SRR.events, " / ", crins.srr$exp.total))
labtext[,3] <- c("control", paste0(crins.srr$cont.SRR.events, " / ", crins.srr$cont.total))
labtext[,4] <- c("log-OR", sprintf("%.3f",crins.srr$yi,2))
labtext[,5] <- c("std. err.", sprintf("%.3f",sqrt(crins.srr$vi),2))
horizl <- list(grid::gpar(col="darkgrey"))
names(horizl) <- as.character(c(2))
q975 <- qnorm(0.975)

# pdf(file="E:/Vellore-Stick/Presentation/Bayes1.pdf", paper="special", width=7, height=2)
forestplot(labeltext=labtext,
           hrzl=horizl,
           mean=c(NA,crins.srr$yi),
           lower=c(NA,crins.srr$yi-q975*sqrt(crins.srr$vi)),
           upper=c(NA,crins.srr$yi+q975*sqrt(crins.srr$vi)),
           xlab="log-OR",
           txt_gp = fpTxtGp(ticks = gpar(cex=1), xlab = gpar(cex=0.9)))
# dev.off()



###################
# MA computations:

tauHat <- c("DL"  =sqrt(rma(crins.srr,method="DL")$tau2),
            "REML"=sqrt(rma(crins.srr,method="REML")$tau2),
            "PM"  =sqrt(rma(crins.srr,method="PM")$tau2))

# uniform prior (for likelihood plot):
crins.ma0 <- bayesmeta(crins.srr)

#crins.ma1 <- bayesmeta(y=crins.srr$yi, sigma=sqrt(crins.srr$vi),
#                       labels=crins.srr$publication,
#                       mu.prior.mean=0, mu.prior.sd=4,
#                       tau.prior=function(x){return(dhalfnormal(x, scale=0.5))})

crins.ma1 <- bayesmeta(crins.srr,
                       mu.prior.mean=0, mu.prior.sd=4,
                       tau.prior=function(x){return(dhalfnormal(x, scale=0.5))})

crins.ma2 <- bayesmeta(crins.srr,
                       mu.prior.mean=0, mu.prior.sd=4,
                       tau.prior=function(x){return(dhalfnormal(x, scale=1.0))})

crins.ma3 <- bayesmeta(crins.srr,
                       mu.prior.mean=0, mu.prior.sd=4,
                       tau.prior=function(x){return(dexp(x, rate=1/0.5))})

ma01 <- bayesmeta(y=c(-1.998, -0.446, -1.877), sigma=c(0.911, 0.676, 1.142),
                  labels=c("Heffron (2003)","Ganschow (2005)","Gras (2008)"),
                  mu.prior.mean=0.0, mu.prior.sd=4.0,
                  tau.prior=function(x){return(dhalfnormal(x, scale=0.5))})

#########################
# joint likelihood plot:
plotsize <- c("height"=5, "width"=5)

#postscript(file="~/lehre/2017-04-InSPiRe/Likelihood.eps", title="R Graphics Output",
#           paper="special", width=plotsize["width"], height=plotsize["height"], horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot.bayesmeta(crins.ma0, which=2, main="",
               maxtau=2.7, murange=c(-3.5,1), likeli=TRUE)
par(mar=c(5,4,4,2)+0.1)
# dev.off()

#########################
# joint posterior plot:
# HN(0.5) prior:
#postscript(file="~/lehre/2017-04-InSPiRe/Posterior01.eps", title="R Graphics Output",
#           paper="special", width=plotsize["width"], height=plotsize["height"], horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot.bayesmeta(crins.ma1, which=2, main="",
               maxtau=2.7, murange=c(-3.5,1))
par(mar=c(5,4,4,2)+0.1)
# dev.off()

#########################
# marginal density plots:

# tau posterior:
#postscript(file="~/lehre/2017-04-InSPiRe/MarginalTau01.eps", title="R Graphics Output",
#           paper="special", width=plotsize["width"], height=plotsize["height"], horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot.bayesmeta(crins.ma1, which=4, main="",
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)
legend("topright", lty=c("dashed", "solid"), leg=c("prior","posterior"),)
par(mar=c(5,4,4,2)+0.1)
# dev.off()

# mu posterior:
#postscript(file="~/lehre/2017-04-InSPiRe/MarginalMu01.eps", title="R Graphics Output",
#           paper="special", width=plotsize["width"], height=plotsize["height"], horiz=F)
par(mar=c(4,4,0,0)+0.1)
plot.bayesmeta(crins.ma1, which=3, main="",
               maxtau=2.7, murange=c(-3.5,1), prior=TRUE)
legend("topright", lty=c("dashed", "solid"), leg=c("prior","posterior"),)
par(mar=c(5,4,4,2)+0.1)
# dev.off()

#######################
# FOREST PLOT:
#postscript(file="~/lehre/2017-04-InSPiRe/CrinsForest02.eps", title="R Graphics Output",
#           paper="special", width=7, height=3, horiz=F)
forestplot(crins.ma1,
           shrink=FALSE,
           xlab="odds ratio", expo=TRUE, xlog=TRUE, digi=3, 
           txt_gp = fpTxtGp(ticks = gpar(cex=1), xlab = gpar(cex=0.9)))
dev.off()

#postscript(file="~/lehre/2017-04-InSPiRe/CrinsForest03.eps", title="R Graphics Output",
#           paper="special", width=7, height=3.5, horiz=F)
forestplot(crins.ma1,
           shrink=TRUE,
           xlab="odds ratio", expo=TRUE, xlog=TRUE, digi=3, 
           txt_gp = fpTxtGp(ticks = gpar(cex=1), xlab = gpar(cex=0.9)))
# dev.off()




