# Use-R! - Meta-Analysis with R by Schwarzer, Carpenter, Rcker
#
# R code for Chapter 9
# "Meta-Analysis of Diagnostic Test Accuracy Studies"
#
#
# Original file slightly modified
library(meta)
library(mada)
# Change working directory - replace 'my_directory' with the path to
# an existing directory containing the data files from the R book
setwd("E:/Vellore-Stick/RPrograms")

# 1. Load MR dataset (Scheidler 1997, Table 3)
data16 <- read.csv("dataset16.csv", as.is=TRUE)
# 2. Print dataset
data16
# 3. Calculate sensitivity
round(data16$tp / data16$n1, 4)
# 4. Calculate specificity
round(data16$tn / data16$n2, 4)
#
# Sensitivity
# Confidence intervals are Pearson-Clopper intervals
metaprop(tp, n1, data=data16,
         comb.fixed=FALSE, comb.random=FALSE,
         studlab=paste(author, year))
#
# Specificity
metaprop(tn, n2, data=data16,
         comb.fixed=FALSE, comb.random=FALSE,
         studlab=paste(author, year))
#
# Diagnostic odds ratio
metabin(tp, n1, n2-tn, n2, data=data16, sm="OR",
        comb.fixed=FALSE, comb.random=FALSE,
        studlab=paste(author, year),
        addincr=TRUE, allstudies=TRUE)
#
# Arguments of function madad
args(madad)
# madad computes Wilson confidence intervals for proportions
#
# The following command generates an error message
# md1 <- madad(data16)
#
# Bring the data in the required format
data16$TP <- data16$tp
data16$FN <- data16$n1 - data16$tp
data16$FP <- data16$n2 - data16$tn
data16$TN <- data16$tn
md1 <- madad(data16)
print(md1, digits=2)
#
# madad(data16, correction.control="none")
#
# pdf(file="Schwarzer-Fig9.2.pdf", width=10) # uncomment line to generate PDF file
# Changes to plot layout:
# - two plots (columns) in one row (argument mfrow)
# - use maximal plotting region (argument pty)
oldpar <- par(mfrow=c(1,2), pty="m")
# Forest plot for sensitivities
forest(md1, type="sens", main="Sensitivity")
# Forest plot for specificities
forest(md1, type="spec", main="Specificity")
# Use previous graphical settings
par(oldpar)
# invisible(dev.off()) # uncomment line to save PDF file
#
# pdf(file="Schwarzer-Fig9.3.pdf", width=6) # uncomment line to generate PDF file
forest(md1, type="DOR", log=TRUE, 
       main="Log diagnostic odds ratio")
# invisible(dev.off()) # uncomment line to save PDF file
#
# pdf(file="Schwarzer-Fig9.6.pdf", width=6) # uncomment line to generate PDF file
oldpar <- par(pty="s") # use a square plotting region
plot(1-md1$spec$spec, md1$sens$sens,
     xlim=c(0,1), ylim=c(0,1),
     xlab="False positive rate (1-Specificity)",
     ylab="Sensitivity", pch=16)
# invisible(dev.off()) # uncomment line to save PDF file
par(oldpar)
#
# pdf(file="Schwarzer-Fig9.7.pdf", width=6) # uncomment line to generate PDF file
oldpar <- par(pty="s") # use a square plotting region
ROCellipse(data16, pch=16)
#invisible(dev.off()) # uncomment line to save PDF file
par(oldpar)
#
# Bivariate model
mrfit <- reitsma(data16)
print(summary(mrfit), digits=2)
#
# pdf(file="Schwarzer-Fig9.8.pdf", width=6) # uncomment line to generate PDF file
oldpar <- par(pty="s") # use a square plotting region
plot(mrfit, predict=TRUE, cex=2, lwd=2)
points(1-md1$spec$spec, md1$sens$sens, pch=16)
# Argument lty=2 gives the dashed line (Moses approach)
mslSROC(data16, lty=2, add=TRUE)
# Argument lty=3 gives the dotted line (Rcker approach)
rsSROC(data16, lty=3, add=TRUE) 
# invisible(dev.off()) # uncomment line to save PDF file
par(oldpar)
