#
# Use-R! - Meta-Analysis with R by Schwarzer, Carpenter, Rcker
#
# R code for Chapter 8
# "Network Meta-Analysis"
#
# Slighty modified by Guido Knapp
#
# 1. Make R package netmeta available
library(netmeta)
###########################################################################
# Patients enrolled in studies were treated with one of ten               #
# diabetes treatments designed to reduce blood glucose levels.            #
# The effect measure was the mean difference of average plasma            #
# glucose concentration, referred to as HbA1c, and measured in mmol/mol.  #
###########################################################################
# 
# More information
help("Senn2013")
#
# 2. Load dataset
data(Senn2013)
data15 <- Senn2013
# 3. Print dataset
data15

# Arguments of netmeta function
args(netmeta)
# Apply netmeta
mn0 <- netmeta(TE, seTE, treat1, treat2, data=data15)
mn0
# Read the warnings!
#
# Redo the analysis and specify the effect measure
mn1 <- netmeta(TE, seTE, treat1, treat2, studlab,
               data=data15, sm="MD")

# A first graphical representation
netgraph(mn1, seq=c("plac", "benf", "migl", "acar", "sulf",
                    "metf", "rosi", "piog", "sita", "vild"))
#
# Results of network meta-nalysis
print(mn1, digits=2)
# Shorter version
print(summary(mn1))
#
# Some further netgraphs
# Random start
netgraph(mn1, start="random", iterate=TRUE,
         col="darkgray", cex=1.5, multiarm=FALSE,
         points=TRUE, col.points="green", cex.points=3)
# Use of stress majorisation algorithm
netgraph(mn1, start="circle", iterate=TRUE,
         col="darkgray", cex=1.5, 
         points=TRUE, col.points="black", cex.points=3, 
         col.multiarm="gray")
#
# Summarizing the output with respect to a reference treatmen
summary(mn1, ref="plac")
# Forest plot
forest(mn1, ref="plac")
# Command results in an error
# forest(mn1)
args(forest.netmeta)
# Modification of Forest Plot
forest(mn1, xlim=c(-1.5, 1), ref="plac",
       leftlabs="Contrast to Placebo",
       xlab="HbA1c difference")
# Random effects results
forest(mn1, xlim=c(-1.5, 1), ref="plac",
       leftlabs="Contrast to placebo",
       xlab="HbA1c difference",
       pooled="random")
#
# Decomposition of Heterogeneity Statistic
round(decomp.design(mn1)$Q.decomp, 3)
#
print(decomp.design(mn1)$Q.het.design, digits=2)
#
round(decomp.design(mn1)$Q.inc.random, 3) 
#
# Net Heat Plot
netheat(mn1)
round(decomp.design(mn1)$Q.inc.design, 2)
netheat(mn1, random=TRUE)
