# Second-hand smoking data
# Data: relative risk (rr) estimates and 95%-confidence intervals
# lb.ci = lower bound of the confidence interval
# ub.ci = upper bound of the confidence interval
rr     <- c(1.52, 1.52, 0.81, 0.75, 2.07, 1.19, 1.31, 2.16, 2.34, 2.55, 0.79, 1.55, 1.65, 2.01, 1.03, 1.28, 1.26, 2.13, 1.41)
lb.ci  <- c(0.88, 0.39, 0.34, 0.43, 0.82, 0.82, 0.87, 1.08, 0.81, 0.74, 0.25, 0.90, 1.16, 1.09, 0.41, 0.76, 0.57, 1.19, 0.54)
ub.ci  <- c(2.63, 5.99, 1.90, 1.30, 5.25, 1.73, 1.98, 4.29, 6.75, 8.78, 2.45, 2.67, 2.35, 3.71, 2.55, 2.15, 2.82, 3.83, 3.67)
#
# Meta-analysis on the log-relative risk scale
# Calculating the standard error
log.rr    <- log(rr)
length.ci <- log(ub.ci) - log(lb.ci)
se.log.rr <- length.ci / (2 * qnorm(0.975))
#
#
# Meta-analysis using metagen function from R package meta
# Load the package
library(meta)
# Generic meta-analysis for log RR
( meta1 <- metagen(log.rr, se.log.rr) )
class(meta1)
#
# Generic meta-analysis for log RR with HKSJ-interval
meta2 <- metagen(log.rr, se.log.rr, hakn=TRUE)
summary(meta2)
#
# Meta-analysis results backtransformed to RR scale
meta3 <- metagen(log.rr, se.log.rr, hakn=TRUE, sm="RR")
summary(meta3)
#
# Meta-analysis results backtransformed to RR scale
# and Paule-Mandel estimator for heterogeneity
meta4 <- metagen(log.rr, se.log.rr, hakn=TRUE, sm="RR", method.tau="PM")
summary(meta4)
#
# Meta-analysis results backtransformed to RR scale
# and Sidik-Jonkman estimator for heterogeneity
# Note: SJ estimator is always positive
meta5 <- metagen(log.rr, se.log.rr, hakn=TRUE, sm="RR", method.tau="SJ")
summary(meta5)
# 
#
# Graphical represenation: Forest plot
forest(meta1)
forest(meta3)
# Some modifications
forest(meta3, comb.random=FALSE)
forest(meta3, comb.random=FALSE, hetstat=FALSE)
forest(meta3, comb.random=FALSE, hetstat=FALSE, smlab=" ", xlab="Risk ratio")

