# load package:
require("bayesmeta")

# load example data set:
data("CrinsEtAl2014")
print(CrinsEtAl2014)

# load "metafor" package:
require("metafor")

# compute effect size (odds ratios) from event counts;
# acute rejection (AR, 6 studies):
crins.ar <- escalc(measure="OR",
                   ai=exp.AR.events,  n1i=exp.total,
                   ci=cont.AR.events, n2i=cont.total,
                   slab=publication,  data=CrinsEtAl2014)
print(crins.ar)
print(crins.ar[c(1,5),])



# steroid-resistant rejection (SRR, 3 studies):
crins.srr <- escalc(measure="OR",
                    ai=exp.SRR.events,  n1i=exp.total,
                    ci=cont.SRR.events, n2i=cont.total,
                    slab=publication,   data=CrinsEtAl2014[c(1,4,6),])
print(crins.srr)



# perform meta analyses;
# for the SRR data you get 3 different results for normal/KnHa/mKH approaches:
rma(crins.srr)
rma(crins.srr, test="knha")
rma(crins.srr, test="adhoc")

# ... and again something different for Paule-Mandel (default was REML):
rma(crins.srr, test="adhoc", method="PM")

# you don't actually need to compute effect sizes in a separate step:
rma(ai=exp.SRR.events, n1i=exp.total, ci=cont.SRR.events, n2i=cont.total,
    measure="OR", slab=publication, data=CrinsEtAl2014[c(1,4,6),],
    test="adhoc", method="PM")

# generate forest plot:
crins.ma <- rma(crins.srr, test="adhoc", method="PM")
forest(crins.ma)

# compare forest plots for normal and mKH results:
forest(rma(crins.srr, method="PM"))
forest(rma(crins.srr, method="PM", test="adhoc"))



#############################################################################
# beispiel: heterogenitaet bei baseline, k(l)eine heterogenitaet im Effekt?
require("bayesmeta")
data("SidikJonkman2007")

pt <- SidikJonkman2007$lihr.events / SidikJonkman2007$lihr.cases
pc <- SidikJonkman2007$oihr.events / SidikJonkman2007$oihr.cases

plot(pc, pt, asp=1, xlim=c(0,1), ylim=c(0,1))
abline(a=0, b=1, h=0:1, v=0:1, col="grey")

plot(log(pc/(1-pc)), log(pt/(1-pt)), asp=1, xlim=c(-4.5,3), ylim=c(-4.5,3))
#abline(h=-4:3, v=-4:4, col="blue")
abline(v=-4:4, col="blue")
for (i in -7:7)
  abline(i,1, col="red")

# baseline heterogeneity:
sd(log(pc/(1-pc)))
# effect heterogeneity:
sd(log(pt/(1-pt)) - log(pc/(1-pc)))


plot(log(pc/(1-pc)), log(pt/(1-pt)) - log(pc/(1-pc)), asp=1)
abline(h=0, v=0)
