#  Crins example figure for April-2017 InSPiRe meeting slides
#  showing THREE studies (SRR endpoint)
#  (evolved from k2CrinsEcample-3.R)


# load necessary libraries:
require("metafor")
require("bayesmeta")

# load data:
data("CrinsEtAl2014")

# compute effect sizes (log-OR for AR in randomized studies)
# using metafor library's "escalc()" function:
effsize <- escalc(measure = "OR",
                  ai = exp.SRR.events,  n1i = exp.total,
                  ci = cont.SRR.events, n2i = cont.total,
                  slab = publication,
                  subset = is.finite(CrinsEtAl2014[,"exp.SRR.events"]),
                  data = CrinsEtAl2014)

print(effsize)

y <- c(-1.998, -0.446, -1.877)
se <- sqrt(c(0.829, 0.457, 1.304))
study <- c("Heffron (2003)", "Ganschow (2005)", "Gras (2008)")

ma01 <- rma(y=y, vi=se^2, slab=study)
print(ma01)
forest(ma01)

ma02 <- rma(y=y, vi=se^2, slab=study, method="PM", test="knha")
ma03 <- rma(y=y, vi=se^2, slab=study, method="PM", test="adhoc")


rma(effsize, method="REML", test="z")
rma(effsize, method="REML", test="knha")
rma(effsize, method="REML", test="adhoc")

tau <- sqrt(c("DL"=rma(effsize, method="DL")$tau2, "ML"=rma(effsize, method="ML")$tau2,
              "REML"=rma(effsize, method="REML")$tau2, "PM"=rma(effsize, method="PM")$tau2))
print(tau)



# compute Bayesian meta-analyses:
bm.hnorm10 <- bayesmeta(effsize, tau.prior = function(x){dhalfnormal(x,scale=1.00)})
bm.hnorm05 <- bayesmeta(effsize, tau.prior = function(x){dhalfnormal(x,scale=0.50)})

# compute frequentist (DerSimonian-Laird) meta-analysis:
rma.REML     <- rma.uni(yi=effsize$yi, vi=effsize$vi)
print(rma.REML)
summary(rma.REML)

# compute corresponding 3 different CIs:
knhaCIs    <- knha(y=effsize$yi, sigma=sqrt(effsize$vi), tau=sqrt(rma.REML$tau2))
# (note: HKSJ and mKH are identical in this particular example)

# assemble estimates (on log-OR scale);
# estimates for tau and mu (posterior medians for Bayesian analyses)
# and 95% interval for mu:
estimates <- rbind("half-normal(1.0)" = c(bm.hnorm10$summary[2,1:2],   bm.hnorm10$summary[5:6,2]),
                   "half-normal(0.5)" = c(bm.hnorm05$summary[2,1:2],   bm.hnorm05$summary[5:6,2]),
                   "normal"     = c(sqrt(rma.REML$tau2), rma.REML$b, knhaCIs[1,]),
                   "HKSJ"       = c(sqrt(rma.REML$tau2), rma.REML$b, knhaCIs[2,]),
                   "mKH"        = c(sqrt(rma.REML$tau2), rma.REML$b, knhaCIs[3,]))
print(estimates)

# show forest plot:
fnames <- paste("/home/christian/lehre/2017-04-InSPiRe/CrinsExample0",1:2,".pdf",sep="")
for (i in 1:2) {
  pdf(file=fnames[i], paper="special", height=ifelse(i==1,3.2,4), width=6)
  par(mar=c(4,0,0,0)+0.1)
    if (i==1) {
      yrange <- c(-5 - nrow(effsize), 1)
    } else {
      yrange <- c(-7 - nrow(effsize), 1)
    }
    forest.default(effsize$yi, vi = effsize$vi, refline = 0,
                   rows = seq(-2, -length(effsize$yi) - 1, by = -1),
                   xlim = c(-9,7), ylim = yrange,
                   xlab="odds ratio", slab = effsize[,"publication"],
                   atransf=exp, at=log(c(0.01, 0.1, 1, 10)), digits=3)
    axis(1, at=log(c(0.02, 0.05,0.2,0.5,2,5)), lab=FALSE, tcl=-0.2)
    title("Crins et al. (2014) example: steroid-resistant graft rejection", line=-1.5)
    colvec <- c("red","green","blue","blue","blue")
    if (i==1) {
      for (j in 1:3)
        addpoly(estimates[j+2,"mu"], ci.lb=estimates[j+2,3], ci.ub=estimates[j+2,4], atransf=exp,
                mlab=row.names(estimates)[j+2], rows=yrange[1]+3.5-j, col=colvec[j+2], digits=3)
    } else {
      for (j in 1:nrow(estimates))
        addpoly(estimates[j,"mu"], ci.lb=estimates[j,3], ci.ub=estimates[j,4], atransf=exp,
                mlab=row.names(estimates)[j], rows=yrange[1]+5.5-j, col=colvec[j], digits=3)
    }
  par(mar=c(5,4,4,2)+0.1)
  dev.off()
}
